Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(76)

Unified Diff: chromeos/dbus/shill_manager_client.h

Issue 289383004: Merge FavoriteState into NetworkState (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/fake_shill_service_client.cc ('k') | chromeos/network/client_cert_resolver.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/shill_manager_client.h
diff --git a/chromeos/dbus/shill_manager_client.h b/chromeos/dbus/shill_manager_client.h
index 73de329ee213308325e949333034cb0bce92076b..23ca24a18b3bcbfdc2a2a810ed4c85bd331dbe5e 100644
--- a/chromeos/dbus/shill_manager_client.h
+++ b/chromeos/dbus/shill_manager_client.h
@@ -62,10 +62,8 @@ class CHROMEOS_EXPORT ShillManagerClient : public DBusClient {
const base::Value& value) = 0;
// Modify services in the Manager's list.
- virtual void AddManagerService(const std::string& service_path,
- bool add_to_visible_list) = 0;
- virtual void RemoveManagerService(const std::string& service_path,
- bool remove_from_complete_list) = 0;
+ virtual void AddManagerService(const std::string& service_path) = 0;
+ virtual void RemoveManagerService(const std::string& service_path) = 0;
virtual void ClearManagerServices() = 0;
// Called by ShillServiceClient when a service's State property changes,
@@ -74,10 +72,11 @@ class CHROMEOS_EXPORT ShillManagerClient : public DBusClient {
virtual void ServiceStateChanged(const std::string& service_path,
const std::string& state) = 0;
- // Called by ShillServiceClient when a service's State property changes,
- // after notifying observers. Services are sorted first by Active or
- // Inactive State, then by Type.
- virtual void SortManagerServices() = 0;
+ // Called by ShillServiceClient when a service's State or Visibile
+ // property changes. If |notify| is true, notifies observers if a list
+ // changed. Services are sorted first by active, inactive, or disabled
+ // state, then by type.
+ virtual void SortManagerServices(bool notify) = 0;
// Sets up the default fake environment based on default initial states
// or states provided by the command line.
« no previous file with comments | « chromeos/dbus/fake_shill_service_client.cc ('k') | chromeos/network/client_cert_resolver.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698